@@ -2,7 +2,7 @@ use strict;
 use warnings;
 use 5.022;
 
-package Alien::Build::Wizard 0.01 {
+package Alien::Build::Wizard 0.02 {
 
   use Moose;
   use Moose::Util::TypeConstraints;
@@ -10,8 +10,11 @@ package Alien::Build::Wizard 0.01 {
   use experimental qw( signatures postderef );
   use Data::Section::Simple qw( get_data_section );
   use Alien::Build::Wizard::Detect;
+  use Alien::Build::Wizard::Questions qw( :all );
   use namespace::autoclean;
 
+  # ABSTRACT: Alien distribution creation wizard
+
   has detect => (
     is       => 'ro',
     isa      => 'Alien::Build::Wizard::Detect',
@@ -19,7 +22,7 @@ package Alien::Build::Wizard 0.01 {
     default => sub ($self) {
       for(1..20)
       {
-        my $url = $self->chrome->ask('Enter the full URL to the latest tarball (or zip, etc.) of the project you want to alienize.');
+        my $url = $self->chrome->ask(QUESTION_URL);
 
         if($url eq '')
         {
@@ -57,7 +60,7 @@ package Alien::Build::Wizard 0.01 {
     isa     => 'Str',
     lazy    => 1,
     default => sub ($self) {
-      $self->chrome->ask('What is the class name for your Alien?', 'Alien::' . $self->detect->name);
+      $self->chrome->ask(QUESTION_CLASS_NAME, 'Alien::' . $self->detect->name);
     },
   );
 
@@ -75,7 +78,7 @@ package Alien::Build::Wizard 0.01 {
     isa     => 'Str',
     lazy    => 1,
     default => sub ($self) {
-      $self->chrome->ask('What is the human project name of the alienized package?', $self->detect->name);
+      $self->chrome->ask(QUESTION_HUMAN_NAME, $self->detect->name);
     },
   );
 
@@ -84,7 +87,7 @@ package Alien::Build::Wizard 0.01 {
     isa     => 'ArrayRef[Str]',
     lazy    => 1,
     default => sub ($self) {
-      [split /\s+/, $self->chrome->ask('Which pkg-config names (if any) should be used to detect system install?  You may space separate multiple names.', join ' ', $self->detect->pkg_config->@*)];
+      [split /\s+/, $self->chrome->ask(QUESTION_PKG_NAMES, join ' ', $self->detect->pkg_config->@*)];
     },
   );
 
@@ -132,10 +135,29 @@ package Alien::Build::Wizard 0.01 {
         $self->chrome->say("Multiple build systems were detected in the tarball; select the most reliable one of: @types");
       }
       my $default = $types[0];
-      $self->chrome->choose("Choose build system.", ['manual','autoconf','cmake','make'], $types[0]);
+      scalar $self->chrome->choose(QUESTION_BUILD_SYSTEM, ['manual','autoconf','cmake','make'], \@types);
     },
   );
 
+  has alien_types => (
+    is      => 'ro',
+    isa     => 'HashRef[Int]',
+    lazy    => 1,
+    default => sub ($self) {
+      while(1)
+      {
+        my @types = $self->chrome->choose(QUESTION_ALIEN_TYPE, ['tool','xs','ffi'], ['xs']);
+        unless(@types)
+        {
+          $self->chrome->say("You must select at least one type");
+          next;
+        }
+        my %answer = map { $_ => 1 } @types;
+        return \%answer;
+      }
+    }
+  );
+
   sub generate_content ($self)
   {
     my %files;
@@ -175,11 +197,11 @@ package Alien::Build::Wizard;
 
 =head1 NAME
 
-Alien::Build::Wizard
+Alien::Build::Wizard - Alien distribution creation wizard
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -227,8 +249,76 @@ use 5.008004;
 [% wizard.class_name %] - Find or build [% wizard.human_name %]
 
 =head1 SYNOPSIS
+[%- IF wizard.alien_types.xs %]
 
- # TODO
+From L<ExtUtils::MakeMaker>:
+
+ use ExtUtils::MakeMaker;
+ use Alien::Base::Wrapper ();
+ 
+ WriteMakefile(
+   Alien::Base::Wrapper->new('[% wizard.class_name %]')->mm_args2(
+     NAME => 'FOO::XS',
+     ...
+   ),
+ );
+
+From L<Module::Build>:
+
+ use Module::Build;
+ use Alien::Base::Wrapper qw( [% wizard.class_name %] !export );
+ use [% wizard.class_name %];
+ 
+ my $build = Module::Build->new(
+   ...
+   configure_requires => {
+     'Alien::Base::Wrapper' => '0',
+     '[% wizard.class_name %]' => '0',
+     ...
+   },
+   Alien::Base::Wrapper->mb_args,
+   ...
+ );
+ 
+ $build->create_build_script;
+
+From L<Inline::C> / L<Inline::CPP> script:
+
+ use Inline 0.56 with => '[% wizard.class_name %]';
+
+From L<Dist::Zilla>
+
+ [@Filter]
+ -bundle = @Basic
+ -remove = MakeMaker
+ 
+ [Prereqs / ConfigureRequires]
+ [% wizard.class_name %] = 0
+ 
+ [MakeMaker::Awesome]
+ header = use Alien::Base::Wrapper qw( [% wizard.class_name %] !export );
+ WriteMakefile_arg = Alien::Base::Wrapper->mm_args
+[%- END %]
+[%- IF wizard.alien_types.ffi %]
+
+From L<FFI::Platypus>:
+
+ use FFI::Platypus;
+ use [% wizard.class_name %];
+ 
+ my $ffi = FFI::Platypus->new(
+   lib => [ [% wizard.class_name %]->dynamic_libs ],
+ );
+[%- END %]
+[%- IF wizard.alien_types.tool %]
+
+Command line tool:
+
+ use [% wizard.class_name %];
+ use Env qw( @PATH );
+ 
+ unshift @PATH, [% wizard.class_name %]->bin_dir;
+[%- END %]
 
 =head1 DESCRIPTION
 
@@ -251,6 +341,10 @@ Documentation on the Alien concept itself.
 
 The base class for this Alien.
 
+=item L<Alien::Build::Manual::AlienUser>
+
+Detailed manual for users of Alien classes.
+
 =back
 
 =cut
@@ -285,11 +379,26 @@ share {
   ]
 [% ELSIF wizard.build_type == 'autoconf' -%]
   plugin 'Build::Autoconf';
+[% IF wizard.alien_types.tool AND wizard.alien_types.ffi -%]
   build [
-    '%{configure}',
+    '%{configure} --enable-static --disable-shared',
+    '%{make}',
+    '%{make install',
+  ];
+  ffi {
+    build [
+      '%{configure} --disabled-static --enabled-shared',
+      '%{make}',
+      '%{make install',
+    ];
+  }
+[% ELSE -%]
+  build [
+    '%{configure} --[% IF wizard.alien_types.xs %]enable[% ELSE %]disable[% END %]-static --[% IF wizard.alien_types.ffi %]enable[% ELSE %]disable[% END %]-shared',
     '%{make}',
     '%{make} install',
   ];
+[% END -%]
 [% ELSIF wizard.build_type == 'cmake' -%]
   plugin 'Build::CMake';
   build [
